Class: Aws::VoiceID::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::VoiceID::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-voiceid/client.rb,
sig/client.rbs
Overview
An API client for VoiceID. To construct a client, you need to configure a :region and :credentials.
client = Aws::VoiceID::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateFraudsterResponseSuccess, _CreateDomainResponseSuccess, _CreateWatchlistResponseSuccess, _DescribeDomainResponseSuccess, _DescribeFraudsterRegistrationJobResponseSuccess, _DescribeFraudsterResponseSuccess, _DescribeSpeakerEnrollmentJobResponseSuccess, _DescribeSpeakerResponseSuccess, _DescribeWatchlistResponseSuccess, _DisassociateFraudsterResponseSuccess, _EvaluateSessionResponseSuccess, _ListDomainsResponseSuccess, _ListFraudsterRegistrationJobsResponseSuccess, _ListFraudstersResponseSuccess, _ListSpeakerEnrollmentJobsResponseSuccess, _ListSpeakersResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWatchlistsResponseSuccess, _OptOutSpeakerResponseSuccess, _StartFraudsterRegistrationJobResponseSuccess, _StartSpeakerEnrollmentJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDomainResponseSuccess, _UpdateWatchlistResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_fraudster(params = {}) ⇒ Types::AssociateFraudsterResponse
Associates the fraudsters with the watchlist specified in the same domain.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain that contains all Amazon Connect Voice ID data, such as speakers, fraudsters, customer audio, and voiceprints.
-
#create_watchlist(params = {}) ⇒ Types::CreateWatchlistResponse
Creates a watchlist that fraudsters can be a part of.
-
#delete_domain(params = {}) ⇒ Struct
Deletes the specified domain from Voice ID.
-
#delete_fraudster(params = {}) ⇒ Struct
Deletes the specified fraudster from Voice ID.
-
#delete_speaker(params = {}) ⇒ Struct
Deletes the specified speaker from Voice ID.
-
#delete_watchlist(params = {}) ⇒ Struct
Deletes the specified watchlist from Voice ID.
-
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the specified domain.
-
#describe_fraudster(params = {}) ⇒ Types::DescribeFraudsterResponse
Describes the specified fraudster.
-
#describe_fraudster_registration_job(params = {}) ⇒ Types::DescribeFraudsterRegistrationJobResponse
Describes the specified fraudster registration job.
-
#describe_speaker(params = {}) ⇒ Types::DescribeSpeakerResponse
Describes the specified speaker.
-
#describe_speaker_enrollment_job(params = {}) ⇒ Types::DescribeSpeakerEnrollmentJobResponse
Describes the specified speaker enrollment job.
-
#describe_watchlist(params = {}) ⇒ Types::DescribeWatchlistResponse
Describes the specified watchlist.
-
#disassociate_fraudster(params = {}) ⇒ Types::DisassociateFraudsterResponse
Disassociates the fraudsters from the watchlist specified.
-
#evaluate_session(params = {}) ⇒ Types::EvaluateSessionResponse
Evaluates a specified session based on audio data accumulated during a streaming Amazon Connect Voice ID call.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all the domains in the Amazon Web Services account.
-
#list_fraudster_registration_jobs(params = {}) ⇒ Types::ListFraudsterRegistrationJobsResponse
Lists all the fraudster registration jobs in the domain with the given
JobStatus. -
#list_fraudsters(params = {}) ⇒ Types::ListFraudstersResponse
Lists all fraudsters in a specified watchlist or domain.
-
#list_speaker_enrollment_jobs(params = {}) ⇒ Types::ListSpeakerEnrollmentJobsResponse
Lists all the speaker enrollment jobs in the domain with the specified
JobStatus. -
#list_speakers(params = {}) ⇒ Types::ListSpeakersResponse
Lists all speakers in a specified domain.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a specified Voice ID resource.
-
#list_watchlists(params = {}) ⇒ Types::ListWatchlistsResponse
Lists all watchlists in a specified domain.
-
#opt_out_speaker(params = {}) ⇒ Types::OptOutSpeakerResponse
Opts out a speaker from Voice ID.
-
#start_fraudster_registration_job(params = {}) ⇒ Types::StartFraudsterRegistrationJobResponse
Starts a new batch fraudster registration job using provided details.
-
#start_speaker_enrollment_job(params = {}) ⇒ Types::StartSpeakerEnrollmentJobResponse
Starts a new batch speaker enrollment job using specified details.
-
#tag_resource(params = {}) ⇒ Struct
Tags a Voice ID resource with the provided list of tags.
-
#untag_resource(params = {}) ⇒ Struct
Removes specified tags from a specified Amazon Connect Voice ID resource.
-
#update_domain(params = {}) ⇒ Types::UpdateDomainResponse
Updates the specified domain.
-
#update_watchlist(params = {}) ⇒ Types::UpdateWatchlistResponse
Updates the specified watchlist.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-voiceid/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1944 1945 1946 |
# File 'lib/aws-sdk-voiceid/client.rb', line 1944 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1947 1948 1949 |
# File 'lib/aws-sdk-voiceid/client.rb', line 1947 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_fraudster(params = {}) ⇒ Types::AssociateFraudsterResponse
Associates the fraudsters with the watchlist specified in the same domain.
87 |
# File 'sig/client.rbs', line 87
def associate_fraudster: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/aws-sdk-voiceid/client.rb', line 1917 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::VoiceID') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-voiceid' context[:gem_version] = '1.60.0' Seahorse::Client::Request.new(handlers, context) end |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain that contains all Amazon Connect Voice ID data, such as speakers, fraudsters, customer audio, and voiceprints. Every domain is created with a default watchlist that fraudsters can be a part of.
99 |
# File 'sig/client.rbs', line 99
def create_domain: (
|
#create_watchlist(params = {}) ⇒ Types::CreateWatchlistResponse
Creates a watchlist that fraudsters can be a part of.
120 |
# File 'sig/client.rbs', line 120
def create_watchlist: (
|
#delete_domain(params = {}) ⇒ Struct
Deletes the specified domain from Voice ID.
129 |
# File 'sig/client.rbs', line 129
def delete_domain: (
|
#delete_fraudster(params = {}) ⇒ Struct
Deletes the specified fraudster from Voice ID. This action disassociates the fraudster from any watchlists it is a part of.
135 |
# File 'sig/client.rbs', line 135
def delete_fraudster: (
|
#delete_speaker(params = {}) ⇒ Struct
Deletes the specified speaker from Voice ID.
142 |
# File 'sig/client.rbs', line 142
def delete_speaker: (
|
#delete_watchlist(params = {}) ⇒ Struct
Deletes the specified watchlist from Voice ID. This API throws an exception when there are fraudsters in the watchlist that you are trying to delete. You must delete the fraudsters, and then delete the watchlist. Every domain has a default watchlist which cannot be deleted.
149 |
# File 'sig/client.rbs', line 149
def delete_watchlist: (
|
#describe_domain(params = {}) ⇒ Types::DescribeDomainResponse
Describes the specified domain.
160 |
# File 'sig/client.rbs', line 160
def describe_domain: (
|
#describe_fraudster(params = {}) ⇒ Types::DescribeFraudsterResponse
Describes the specified fraudster.
170 |
# File 'sig/client.rbs', line 170
def describe_fraudster: (
|
#describe_fraudster_registration_job(params = {}) ⇒ Types::DescribeFraudsterRegistrationJobResponse
Describes the specified fraudster registration job.
181 |
# File 'sig/client.rbs', line 181
def describe_fraudster_registration_job: (
|
#describe_speaker(params = {}) ⇒ Types::DescribeSpeakerResponse
Describes the specified speaker.
192 |
# File 'sig/client.rbs', line 192
def describe_speaker: (
|
#describe_speaker_enrollment_job(params = {}) ⇒ Types::DescribeSpeakerEnrollmentJobResponse
Describes the specified speaker enrollment job.
203 |
# File 'sig/client.rbs', line 203
def describe_speaker_enrollment_job: (
|
#describe_watchlist(params = {}) ⇒ Types::DescribeWatchlistResponse
Describes the specified watchlist.
214 |
# File 'sig/client.rbs', line 214
def describe_watchlist: (
|
#disassociate_fraudster(params = {}) ⇒ Types::DisassociateFraudsterResponse
Disassociates the fraudsters from the watchlist specified. Voice ID
always expects a fraudster to be a part of at least one watchlist. If
you try to disassociate a fraudster from its only watchlist, a
ValidationException is thrown.
225 |
# File 'sig/client.rbs', line 225
def disassociate_fraudster: (
|
#evaluate_session(params = {}) ⇒ Types::EvaluateSessionResponse
Evaluates a specified session based on audio data accumulated during a streaming Amazon Connect Voice ID call.
242 |
# File 'sig/client.rbs', line 242
def evaluate_session: (
|
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all the domains in the Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
254 |
# File 'sig/client.rbs', line 254
def list_domains: (
|
#list_fraudster_registration_jobs(params = {}) ⇒ Types::ListFraudsterRegistrationJobsResponse
Lists all the fraudster registration jobs in the domain with the given
JobStatus. If JobStatus is not provided, this lists all fraudster
registration jobs in the given domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
266 |
# File 'sig/client.rbs', line 266
def list_fraudster_registration_jobs: (
|
#list_fraudsters(params = {}) ⇒ Types::ListFraudstersResponse
Lists all fraudsters in a specified watchlist or domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
280 |
# File 'sig/client.rbs', line 280
def list_fraudsters: (
|
#list_speaker_enrollment_jobs(params = {}) ⇒ Types::ListSpeakerEnrollmentJobsResponse
Lists all the speaker enrollment jobs in the domain with the specified
JobStatus. If JobStatus is not provided, this lists all jobs with
all possible speaker enrollment job statuses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
294 |
# File 'sig/client.rbs', line 294
def list_speaker_enrollment_jobs: (
|
#list_speakers(params = {}) ⇒ Types::ListSpeakersResponse
Lists all speakers in a specified domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
308 |
# File 'sig/client.rbs', line 308
def list_speakers: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a specified Voice ID resource.
320 |
# File 'sig/client.rbs', line 320
def list_tags_for_resource: (
|
#list_watchlists(params = {}) ⇒ Types::ListWatchlistsResponse
Lists all watchlists in a specified domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
331 |
# File 'sig/client.rbs', line 331
def list_watchlists: (
|
#opt_out_speaker(params = {}) ⇒ Types::OptOutSpeakerResponse
Opts out a speaker from Voice ID. A speaker can be opted out regardless of whether or not they already exist in Voice ID. If they don't yet exist, a new speaker is created in an opted out state. If they already exist, their existing status is overridden and they are opted out. Enrollment and evaluation authentication requests are rejected for opted out speakers, and opted out speakers have no voice embeddings stored in Voice ID.
343 |
# File 'sig/client.rbs', line 343
def opt_out_speaker: (
|
#start_fraudster_registration_job(params = {}) ⇒ Types::StartFraudsterRegistrationJobResponse
Starts a new batch fraudster registration job using provided details.
354 |
# File 'sig/client.rbs', line 354
def start_fraudster_registration_job: (
|
#start_speaker_enrollment_job(params = {}) ⇒ Types::StartSpeakerEnrollmentJobResponse
Starts a new batch speaker enrollment job using specified details.
379 |
# File 'sig/client.rbs', line 379
def start_speaker_enrollment_job: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a Voice ID resource with the provided list of tags.
406 |
# File 'sig/client.rbs', line 406
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes specified tags from a specified Amazon Connect Voice ID resource.
421 |
# File 'sig/client.rbs', line 421
def untag_resource: (
|
#update_domain(params = {}) ⇒ Types::UpdateDomainResponse
Updates the specified domain. This API has clobber behavior, and clears and replaces all attributes. If an optional field, such as 'Description' is not provided, it is removed from the domain.
432 |
# File 'sig/client.rbs', line 432
def update_domain: (
|
#update_watchlist(params = {}) ⇒ Types::UpdateWatchlistResponse
Updates the specified watchlist. Every domain has a default watchlist which cannot be updated.
447 |
# File 'sig/client.rbs', line 447
def update_watchlist: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1937 1938 1939 |
# File 'lib/aws-sdk-voiceid/client.rb', line 1937 def waiter_names [] end |