Class: Aws::VoiceID::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::VoiceID::Types::ConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-voiceid/types.rb
Overview
The request failed due to a conflict. Check the ConflictType and
error message for more details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conflict_type ⇒ String
The type of conflict which caused a ConflictException.
- #message ⇒ String
Instance Attribute Details
#conflict_type ⇒ String
The type of conflict which caused a ConflictException. Possible types and the corresponding error messages are as follows:
-
DOMAIN_NOT_ACTIVE: The domain is not active. -
CANNOT_CHANGE_SPEAKER_AFTER_ENROLLMENT: You cannot change the speaker ID after an enrollment has been requested. -
ENROLLMENT_ALREADY_EXISTS: There is already an enrollment for this session. -
SPEAKER_NOT_SET: You must set the speaker ID before requesting an enrollment. -
SPEAKER_OPTED_OUT: You cannot request an enrollment for an opted out speaker. -
CONCURRENT_CHANGES: The request could not be processed as the resource was modified by another request during execution.
171 172 173 174 175 176 |
# File 'lib/aws-sdk-voiceid/types.rb', line 171 class ConflictException < Struct.new( :conflict_type, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
171 172 173 174 175 176 |
# File 'lib/aws-sdk-voiceid/types.rb', line 171 class ConflictException < Struct.new( :conflict_type, :message) SENSITIVE = [] include Aws::Structure end |